/*
 * Constants.java
 *
 * Created on 15 mai 2002
 */
 
/** Class Constants <p>
 * This class contains all the constants of the problem. It reads the constants from the
 * constants file and stores them in the class attributes.
 * Company:      ONERA/DCSD/CD<p>
 * @author Matthieu Lombard mlombard@operamail.com
 * @version 0.0
 * @see SolutionCheck
 */

import java.util.*;
import java.io.*;

public class Constants {

//-----------------------------------------------------------------------------------
//*******************            A T T R I B U T E S            *********************
//-----------------------------------------------------------------------------------
  //read attributes
  /** altitude of the satellite in meters */
  protected static double Hs;
  /** speed of rotation of the satellite on itself in radians per second */
  protected static double Vr;
  /** minimum transition time in seconds */
  protected static double Dmin;
 
//-----------------------------------------------------------------------------------
//*******************         C O N S T R U C T O R S            ********************
//----------------------------------------------------------------------------------- 
  //-----------------------------------Request---------------------------------
  public Constants ( String fileName){
  
    readConstants(fileName);
    
  }//Constants

//-----------------------------------------------------------------------------------
//*******************              M E T H O D S                 ********************
//----------------------------------------------------------------------------------- 
  //------------------------------readConstants--------------------------------
  public void readConstants(String fileName){

    String line;
    StringTokenizer st;
    File f = new File(fileName);
    
    try {
         System.out.println("\nReading constants file " + fileName + " ...");
         // reading of the file with a BufferedReader
         BufferedReader br = new BufferedReader(new FileReader(f));
         
         //altitude of the satellite read in kilometers and converted in meters
         line = br.readLine();
         st = new StringTokenizer(line," ");
         this.Hs = (Double.valueOf(st.nextToken())).doubleValue()*1000;
         
         //speed of rotation of the satellite
         this.Vr = (Double.valueOf(st.nextToken())).doubleValue();
         
         // minimum transition time
         this.Dmin = (Double.valueOf(st.nextToken())).doubleValue();
    }

    catch ( Exception e ) {
            System.out.println("*** Error when reading the constants file : "
                               + fileName);
            e.printStackTrace();
            System.exit(1);
    }

  }//readConstants

  //-----------------------------------toString--------------------------------
  public String toString(){
    return "Constants : "
      + "{Hs="+ this.Hs
      + "; Vr="+ this.Vr
      + "; Dmin="+ this.Dmin +"}";
  }//toString

}//Constants
